# On peut passer des options à makelmdz
local=`pwd`
\mv -f gcm.e gcm.$$

cd ../
if [ "`grep COMPILER arch/arch-local.fcm  | awk ' { print $2 } '`" = "gfortran" ] ; then
   para=""
else
   para="-mem -parallel mpi_omp"
fi
./makelmdz_fcm $* -rrtm true -d 48x36x39 -arch local $para gcm -v orchidee2.0
cd -
\cp -f ../bin/gcm_48x36x39_phylmd_para_mem_orch.e gcm.e

# BRICOLAGE. Ici on ne compile pas avec les options isotopes
#mv bin/gcm_48x36x39_phylmdiso_para_mem_iso_isoverif.e $local/gcm_iso.e

