# paramètres isotopiques principaux

ok_iso_verif=y

# lambda: supersaturation: valeurs typiques: 0.002. Range possible: 0 (pas de sursat) à 0.004 (forte sursat)
lambda=0.002

# thumxt1: gère le fractionnement cinétique lors de la réévaporation des gouttes. Valeur typique: 0.9. Range possible: 0 (rh au contact des gouttes = rh autour des gouttes, fort fractionnement cinétique) à 1 (rh=1 au contact des gouttes, pas de fractionnement cinétique)
thumxt1=0.9

# h_land_ice: hauteur caractéristique de la glace de terre: la glace de terre à t+1 est égale à h_land_ice de glace de terre à t + la precip neigeuse en t.
#Valeur typique: 20m. Range possible: proche de 0 (-> la glace de terre prend la composition de la dernière précip neigeuse) à très grand (-> la compo de la glace de terre est constante)
h_land_ice=20.

# P_veg: fraction de l evaporation continentale provenant de la transpiration sans fractionnement de la végétation, au lieu de l évaporation avec fractionnement de sol nu ou d eau libre. Valeur standard: 1 (comme autres GCMs). Range possible: 0 à 1.
P_veg=1.0

# bidouille_anti_divergence: si T: on rappel régulièrement l isotope H2O16 vers l eau normale. Si F: pas de rappel. En général, on met T pour être sur, mais on a verifie que ça a peut d importance
bidouille_anti_divergence=y

# essai_convergence: si T, on fait tout exactement comme pour l eau normale, pour que les 2 versions convergent. Si F, on modifie un peu: ex: initialisations supplémentaires de variables, on zappe l homogénéisation sous le nuage dans cv3_yield...
essai_convergence=n

# initialisation_iso: la façon dont les isos sont initialisés.
#   - Lors du lancement de gcm:
#	Pour la physique:
#	0: lecture d un fichier, souvent de start (phyiso_etat0_fichier.F)
#	>0: initialisation des isotopes académique, donnée dans phyiso_etat0_dur.F
#	Pour la dynamique:
#	0: lecture d un fichier (dyniso_etat0_fichier.F)
#	>0: initialisation académique:
#		1: isos à 0 sauf H2016=eau normale
#		2: distill de Rayleigh
#		3: tout est uniforme au SMOW
#	En général, on met initialisation_iso=0
#   - Lors du lancement de create_etat0_limit:
#	Pour la physique: initialisation en dure, toujours
#	Pour la dynamique: initialisation académique toujours:
#		1: isos à 0 sauf H2016=eau normale
#		2 ou 0: distill de Rayleigh
#		3: tout est uniforme au SMOW
#	En général, on laisse à initialisation_iso=0
initialisation_iso=2

# initialisation_isotrac: comment initialiser les traceurs d'eau?
# 1: idéalisé: on met toute l'eau dans le tag izone_init, 0 ailleurs
# 0: en lisant dans un fichier. Possible seulement si initialisation_iso=0
initialisation_isotrac=1

# modif_sst: 0 par defaut, 1 si on veut modifier la sst de manière uniforme
# si 2, on impose un profil de changement de SST, avec 0 entre sstlatcrit et - sstlatcrit en latitude. Ailleurs: +deltaTtestpoles (rlat(ii)**2-sstlatcrit**2) /(90.0**2-sstlatcrit**2)
# si 2, on impose changement de SST linéaire par morceau: 0 entre sstlatcrit et - sstlatcrit, deltaTtestpoles poleward of sstlatcrit+dsstlatcrit, et linéaire entre les 2.
modif_sst=0

# deltaTtest: sensibilité à une variation uniforme de la SST. Utilise seulement si modif_sst=1
deltaTtest=0.0

deltaTtestpoles=-15.0
sstlatcrit=30.0
dsstlatcrit=20.0

# deltaO18_oce: deltaO18 de l'océan: ex: +1.1 au LGM, 0 actuellement. On suppose que le dexcess et O17excess océan sont nuls.
deltaO18_oce=0.0

# deltaP_BL:  epaisseur de la couche limite avec laquelle l'eau du sol tend à se rééquilibrer. Par défaut: 10mb (optim dans ORCHIDEE_LMDZ)
deltaP_BL=10.0 

# ruissellement_pluie: qu'est-ce qui ruisselle? si 1: c'est la pluie qui ruisselle. elle ne s'infiltre. elle ne s'infiltre donc jamais dans un sol saturé. si 0: c'est le sol qui ruisselle. La pluie s'inglitre donc dans le sol saturé.
ruissellement_pluie=1

# alphak_stewart: si 1: alphak=(D/Diso)^nsol. si 0: alphak=1/(1-kcin(vsurf))
alphak_stewart=1

# tdifexp_sol: tdifexp_sol est l'exposant de D/Diso. Il paramétrise la turbulence. D'abitude, il est de 0.58. Mais d'après Mathieu et Bariac, il est entre 0.67 et 1: 0.67 pour les sols secs et 1 pour les sols saturés.
tdifexp_sol=0.67

# calendrier_guide: si 1, on fait en sorte que l'année puisse avoir 365 ou 366 jours. Si 0, l'année à 360 jours (c'est LMDZ par défaut).
# mettre 1 quand on guide, 0 sinon.
calendrier_guide=0

# cste_surf_cond: si 2, la témprature et la rh de surface sont constantes: rhs=0.7 et Ts=15°=288K. si 1: la rh de surface est conste égale à 0.7. Par défaut, cste_surf_cond=0: tout est explicit.
cste_surf_cond=0

# lev_histiso
# niveaux de sorties pour les isotopes et aussi sans les isotopes.
# Pas encore utilisé
lev_histiso=1

# lev_histiso_diag
# ne s applique que si DIAGISO. 1 par defaut. si 0, seul xtvp est outputé
lev_histiso_diag=1

# deltaD aberrant: si on le dépasse, on plante
deltalim=1000.0

# deltaD aberrant pour les traceurs
deltalimtrac=1000000.0
dexcess_max=2000
dexcess_min=-1000

# est-ce qu'on verifie l'O17? 
O17_verif=y
o17excess_bas=-1000.0
o17excess_haut=900.0
nlevmaxO17=18

# pour que les continents évaporent une compositon constante, pour voir si les cycles de dexcess en Amazonie sont liés à la compo de l''évap sur continent
# par défaut: evap_cont_cste=0
# si evap_cont_cste=1, préciser deltaO18 et dexcess de l''évap
evap_cont_cste=0
deltaO18_evap_cont=-5.0
d_evap_cont=14.0

# quand on utilise tag 17, on taggue la vapeur résiduelle quand la fraction condensée est supérieure à seuil_tag_tmin, c'est à dire quand l'évènement de condensation affecte suffisemment la compo de la vapeur résiduelle. Si seuil_tag_tmin=0, le moindre évènement de condensation même très faibel agit sur les tags, et les proportions de sfc, condensat et rev sont presques nulles.
# par defaut: seuil_tag_tmin=0.01: 1% de condensation <-> 0.1 permil d'effet sur la vapeur résiduelle.
seuil_tag_tmin=0.01

# idem pour condensation dans LS: par defaut égal à seuil_tag_tmin
seuil_tag_tmin_ls=0.01

# option_seuil_tag_tmin: si 1, on recolorise la vapeur résiduelle dès que cond/qt>seuil_tag_tmin. Ca taggue bien la vap résiduelle mais le problème est que plus on humidifie par la microphysique, plus le seuil est facilement attent -> plus on retaggue -> au final, on n'a pas plus de tag mcrophysique alors que c'est la sourec d'humdification.
# dans l'option 2: on taggue si (cond-qmicro)/((qt-qmicro)>seuil
option_seuil_tag_tmin=2

# desactivier post-condensational exchanges comme dans Field, Jones et Brown à réviewer
no_pce=0

# latitude de taggage des extra-tropiques quand option de taggage n° 20
# 35.0 par défaut
lim_tag20=35.0

# quand tag9, recolorise t'on que le condensat convectif (option 2) ou aussi le condensat starti (otion 1)
option_cond=2

# quand tag 22, on recolorise la vapeur dans les zones ou precip>lim_precip_tag22
# 10.0 par défaut
lim_precip_tag22=10.0

# quand adv 14, saturation limiter tel que on advec min (q,A_satlim*qs)
# par defaut, A_satlim=1: c'est le code original de Francis Codron
# ce param n'a d'effet que quand adv 14.
A_satlim=0.8

# si ok_restrict_A_satlim=1, alors on n'active adv 14 que dans les extra-tropiques
# si ok_restrict_A_satlim=2, alors on n'active adv 14 que dans les tropiques
# si ok_restrict_A_satlim=3, alors on n'active adv 14 nulle part
ok_restrict_A_satlim=0

slope_limiter=2.0
# defaut: 2; pour adv 10: 0

#on multiplie par 3 ratqs aux extraropiques si modif_ratqs=1.
modif_ratqs=0

