#!/bin/bash


echo '########################################'
echo Lancement du modele
echo '########################################'

\rm listing

if [ "`grep mpi ../arch.fcm`" = "" ] ; then
   echo EXECUTION SEQUENTIELLE
   date ; time ./gcm.e > listing ; date
else
   echo EXECUTION PARALLELE
   date ; time ./run_local.sh 2 2 ./gcm.e > listing ; date
fi
grep GLOB listing

