##############################################################################
# PARAMETRES ET CLES DE CONFIGURATION LMDZ
##############################################################################
# D: Valeur par default
#
# Controle des sorties
#*********************
OK_journe=y
OK_mensuel=y
ok_hf=y
OK_instan=n
ok_LES=n
#ok_regdyn : y/n calcul/non des regymes dynamiques sur regions pre-definies
ok_regdyn=y
# A transformer en la ligne ci-dessous quand ce sera compatible avec libIGCM
ok_sync=y
phys_out_filekeys=       y       y       y       n       n
phys_out_filenames=      histmth histday histhf  histins histLES
phys_out_filetimesteps=  5day    1day    2hr     6hr     6hr
phys_out_filelevels=     5       10      5       4       4
phys_out_filetypes=      ave(X)  ave(X)  ave(X) inst(X) inst(X)

#
#Couplage avec autres modules
#******************************
#option de couplage pour ocean (D:force)
type_ocean=force
version_ocean=nemo
#avec ou sans orchidee (D:n)
VEGET=n
#type_run=AMIP, ENSP, clim (D:AMIP)
type_run=CLIM
##  Soil Model  ou non               
soil_model=y

#Code de transfert radiatif
#**************************
# ajout de ce flag pour activer/desactiver le rayonnement (MPL)
# 0 : pas de rayonnement. 1: on active le rayonnement (D=1)
iflag_radia=1
## Nombre appels des routines de rayonnements ( par jour)                 
nbapp_rad=12

# Parametres "orbitaux/ ere geologique"
#######################################
#Parametres orbitaux
#excentricite
R_ecc=0.016715
#equinoxe
R_peri=102.7
#inclinaison
R_incl=23.441
#constante solaire
solaire=1366.0896
##  Facteur additif pour l albedo
pmagic=0.008
#
# Taux gaz a effet de serre
#######################################
#concentration des gaz (co2 ch4   n2o  cfc11 cfc12)
#                  (D: 348. 1650. 306.  280.  484.)
co2_ppm=0.36886500E+03
#RCO2=co2_ppm * 1.0e-06  * 44.011/28.97= 5.286789092164308E-04
CH4_ppb=0.17510225E+04
#RCH4=1.65E-06* 16.043/28.97= 9.137366240938903E-07
N2O_ppb=0.31585000E+03
#RN2O=306.E-09* 44.013/28.97= 4.648939592682085E-07
CFC11_ppt=5.18015181E+01
#RCFC11=280.E-12* 137.3686/28.97= 1.327690990680013E-09
CFC12_ppt=0.99862742E+03
#RCFC12=484.E-12* 120.9140/28.97= 2.020102726958923E-09
#
# Parametres effets directs/indirects des "aerosols"
#######################################
### ok_ade=y/n   flag Aerosol direct effect
ok_ade=n
### ok_aie=y/n   flag Aerosol indirect effect
ok_aie=n
### aer_type =   Aerosol variation type : actuel / preind / scenario / annuel
aer_type=actuel
###  type of coupled aerosol =1 (default) =2 => bc  only =3 => pom only =4 => seasalt only =5 => dust only =6 => all aerosol
flag_aerosol=0
ok_cdnc=n
### bl95_b0 =    Parameter in CDNC-maer link (Boucher&Lohmann 1995)
bl95_b0=1.7
### bl95_b1 =    Parameter in CDNC-maer link (Boucher&Lohmann 1995)
bl95_b1=0.2
#
# Parametre de lecture de l'ozone
#######################################
# Allowed values are 0, 1 and 2
# 0: do not read an ozone climatology
# 1: read a single ozone climatology that will be used day and night
# 2: read two ozone climatologies, the average day and night climatology and the daylight climatology
read_climoz=0
#
# Parametres simulateur COSP (CFMIP Observational Simulator Package)
#######################################
### ok_cosp=y/n flag simulateur COSP
ok_cosp=n
### freq_COSP = frequence d'appel de COSP en secondes
freq_COSP=10800.
### ok_mensuelCOSP=y/n sortir fichier mensuel COSP histmthCOSP.nc, =n pas de fichier histmthCOSP.nc
ok_mensuelCOSP=y
### ok_journeCOSP=y/n sortir fichier journalier histdayCOSP.nc, =n pas de fichier histdayCOSP.nc
ok_journeCOSP=y
### ok_hfCOSP=y/n, ecrire sorties  haute frequence histhfCOSP.nc, =n pas de fichier histhfCOSP.nc
ok_hfCOSP=n
#
# Parametres simulateur ISCCP
#######################################
### ok_isccp=y/n flag simulateur ISCCP
ok_isccp=n
### top_height = flag choix calcul nuages par le simulateur en utilisant 
# -              les donnees IR et/ou VIS et l algorithme ISCCP-D1
# - top_height = 1 -> algo IR-VIS
# - top_height = 2 -> identique a 1, mais "ptop(ibox)=pfull(ilev)"
# - top_height = 3 -> algo IR
top_height = 1
### overlap =    Hypothese de Recouvrement (HR) utilisee pour le simulateur ISCCP
# - overlap=1    Max overlap
# - overlap=2    Random overlap
# - overlap=3    Max/Random overlap
overlap = 3
#

