# On peut passer des options à makelmdz
local=`pwd`
\mv -f gcm.e gcm.$$

cd ../
if [ "`grep COMPILER arch/arch-local.fcm  | awk ' { print $2 } '`" = "gfortran" ] ; then
   para=""
else
   para="-mem -parallel mpi_omp"
fi

#./makelmdz $* -rrtm true -cpp ORCHIDEE_NOZ0H -d 48x36x39 -v orchidee2.0 -arch local $para gcm
./makelmdz $* -rrtm true -d 48x36x39 -arch local $para gcm

mv gcm.e $local
